
From: Rusty Lynch <rusty.lynch@intel.com>

Fix a bug where a kprobe still fires when the instruction is predicated
off.  So given the p6=0, and we have an instruction like:

(p6) move loc1=0

we should not be triggering the kprobe.  This is handled by carrying over
the qp section of the original instruction into the break instruction.

Signed-off-by: Anil S Keshavamurthy <anil.s.keshavamurthy@intel.com>
Signed-off-by: Rusty Lynch <Rusty.lynch@intel.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ia64/kernel/kprobes.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff -puN arch/ia64/kernel/kprobes.c~kprobes-ia64-qp-fix arch/ia64/kernel/kprobes.c
--- 25/arch/ia64/kernel/kprobes.c~kprobes-ia64-qp-fix	Fri May 27 15:14:07 2005
+++ 25-akpm/arch/ia64/kernel/kprobes.c	Fri May 27 15:14:07 2005
@@ -115,19 +115,19 @@ int arch_prepare_kprobe(struct kprobe *p
 	case 0:
  		major_opcode = (bundle->quad0.slot0 >> SLOT0_OPCODE_SHIFT);
  		kprobe_inst = bundle->quad0.slot0;
-		bundle->quad0.slot0 = BREAK_INST;
+		bundle->quad0.slot0 = BREAK_INST | (0x3f & kprobe_inst);
 		break;
 	case 1:
  		major_opcode = (bundle->quad1.slot1_p1 >> SLOT1_p1_OPCODE_SHIFT);
  		kprobe_inst = (bundle->quad0.slot1_p0 |
  				(bundle->quad1.slot1_p1 << (64-46)));
-		bundle->quad0.slot1_p0 = BREAK_INST;
+		bundle->quad0.slot1_p0 = BREAK_INST | (0x3f & kprobe_inst);
 		bundle->quad1.slot1_p1 = (BREAK_INST >> (64-46));
 		break;
 	case 2:
  		major_opcode = (bundle->quad1.slot2 >> SLOT2_OPCODE_SHIFT);
  		kprobe_inst = bundle->quad1.slot2;
-		bundle->quad1.slot2 = BREAK_INST;
+		bundle->quad1.slot2 = BREAK_INST | (0x3f & kprobe_inst);
 		break;
 	}
 
_
